@@ -24,12 +24,12 @@
 #' @param mh \code{bv_metropolis} object with settings regarding the acceptance
 #' rate of the Metropolis-Hastings step. See \code{\link{bv_mh}}.
 #' @param fcast \code{bv_fcast} object of forecast options set with
-#' \code{\link{bv_fcast}}. May be set to \code{NULL} to skip forecasting.
-#' Forecasts may also be calculated ex-post using \code{\link{predict.bvar}}.
+#' \code{\link{bv_fcast}}. Ideally forecasts are calculated ex-post using
+#' \code{\link{predict.bvar}}. May be set to \code{NULL} to skip forecasting.
 #' @param irf \code{bv_irf} object with options regarding impulse responses and
-#' forecast error variance decompositions. Set via \code{\link{bv_irf}} or
-#' skipped when set to \code{NULL}. May also be computed ex-post using
-#' \code{\link{irf.bvar}}.
+#' forecast error variance decompositions. Ideally computed ex-post using
+#' \code{\link{irf.bvar}}. Set via \code{\link{bv_irf}} or skipped when set
+#' to \code{NULL}.
 #' @param verbose Logical scalar. Whether to print intermediate results and
 #' progress.
 #'
@@ -172,7 +172,7 @@ bvar <- function(
   } else if(!all(dim(priors[["b"]]) == c(K, M))) {
     stop("Dimensions of prior mean (b) do not match the data.")
   }
-  if(priors[["psi"]][["mode"]] == "auto") {
+  if(any(priors[["psi"]][["mode"]] == "auto")) {
     psi_temp <- auto_psi(Y, lags)
     priors[["psi"]][["mode"]] <- psi_temp[["mode"]]
     priors[["psi"]][["min"]] <- psi_temp[["min"]]
